/*
 * Copyright (c) 2015 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

var reqAppControl = null,
    init = null;

function replyAppCaller(event) {
    var data = null,
        text = event.target.src;

    try {
        /* Construct result data */
        data = new tizen.ApplicationControlData("text", [text]);

        /* Reply to caller */
        reqAppControl.replyResult([data]);
        tizen.application.getCurrentApplication().exit();
    } catch (e) {
        alert("return failed. reason: " + e.message);
        console.error("return failed. reason: " + e.message);
    }
}

function createEmoticonTable() {
    var i = 0,
        j = 0,
        svgImgTag = "",
        svgEmoticon = [];

    for (i = 1; i <= 16; i++) {
      svgImgTag += "<img class='svgEmoticon' src='/image/" + i + ".svg'/>";
    }

    document.getElementById("emoticonTable").innerHTML = "<p>Please choose an emoticon.</p>" + svgImgTag;

    svgEmoticon = document.getElementsByClassName("svgEmoticon");
    for (j = 0; j < svgEmoticon.length; j++) {
        svgEmoticon[j].addEventListener('click', replyAppCaller);
    }
}

function checkAppCaller() {
    reqAppControl = null;

    try {
        reqAppControl = tizen.application.getCurrentApplication().getRequestedAppControl();
    } catch (error) {
        console.error("getCurrentApplication(): " + error.message);
    }

    if (reqAppControl && reqAppControl.appControl.operation === "http://tizen.org/appcontrol/operation/appcall") {
        document.getElementById("calleeIntro").innerHTML = "This application is called by <b>" + reqAppControl.callerAppId +
            "</b><br>with operation: <b>" + reqAppControl.appControl.operation.replace('http://tizen.org/appcontrol/operation/', '') + "</b>";
        document.getElementById("btnClose").style.display = 'none';
        createEmoticonTable();
    } else {
        document.getElementById("calleeIntro").innerHTML = "The application was not launched with Application Control." +
            "<br><br>This application only works when it is called by another application." +
            "<br><br>Please launch it with the application &quot;appCaller&quot;.";
        document.getElementById("dataDiv").style.display = 'none';
    }
}

//Initialize function
init = function() {
    checkAppCaller();

    document.getElementById("btnClose").addEventListener('click', function() {
        try {
            tizen.application.getCurrentApplication().exit();
        } catch (error) {
            console.error("getCurrentApplication(): " + error.message);
        }
    });

    // add eventListener for tizenhwkey
    document.addEventListener('tizenhwkey', function(e) {
        if (e.keyName === "back") {
            try {
                tizen.application.getCurrentApplication().exit();
            } catch (error) {
                console.error("getCurrentApplication(): " + error.message);
            }
        }
    });
};

window.onload = init;
